<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Ziya - Code Assistant</title>
    <link rel="stylesheet" href="/static/ziya.css">
    <link rel="icon" href="/static/favicon.ico" type="image/x-icon">
</head>
<body>
<div id="root"/>
<script src="https://cdn.jsdelivr.net/npm/@babel/standalone@7/babel.min.js"></script>
<script src="https://unpkg.com/react@17/umd/react.production.min.js"></script>
<script src="https://unpkg.com/react-dom@17/umd/react-dom.production.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/marked/marked.min.js"></script>
<script type="text/babel" src="/static/sendPayload.js"></script>
<script type="text/babel" src="/static/app.js"></script>
</body>
</html>
